@@ -27,6 +27,7 @@ What is checked:
     - no trailing whitespace - D002
     - no tabulation for indentation - D003
     - no carriage returns (use unix newlines) - D004
+    - no newline at end of file - D005
 """
 
 import argparse
@@ -93,7 +94,7 @@ def extract_config(args):
         pass
     try:
         cfg['ignore_path'] = split_set_type(parser.get("doc8",
-                                                       "ignore_path"))
+                                                       "ignore-path"))
     except (configparser.NoSectionError, configparser.NoOptionError):
         pass
     try:
@@ -109,6 +110,10 @@ def extract_config(args):
         cfg['verbose'] = parser.getboolean("doc8", "verbose")
     except (configparser.NoSectionError, configparser.NoOptionError):
         pass
+    try:
+        cfg['file_encoding'] = parser.get("doc8", "file-encoding")
+    except (configparser.NoSectionError, configparser.NoOptionError):
+        pass
     try:
         cfg['default_extension'] = parser.get("doc8", "default-extension")
     except (configparser.NoSectionError, configparser.NoOptionError):
@@ -131,6 +136,7 @@ def fetch_checks(cfg):
         checks.CheckIndentationNoTab(cfg),
         checks.CheckCarriageReturn(cfg),
         checks.CheckMaxLineLength(cfg),
+        checks.CheckNewlineEndOfFile(cfg),
     ]
     mgr = extension.ExtensionManager(
         namespace='doc8.extension.check',
@@ -160,6 +166,7 @@ def scan(cfg):
     file_iter = utils.find_files(cfg.get('paths', []),
                                  cfg.get('extension', []), ignored_paths)
     default_extension = cfg.get('default_extension')
+    file_encoding = cfg.get('file_encoding')
     for filename, ignoreable in file_iter:
         if ignoreable:
             files_ignored += 1
@@ -167,7 +174,8 @@ def scan(cfg):
                 print("  Ignoring '%s'" % (filename))
         else:
             f = file_parser.parse(filename,
-                                  default_extension=default_extension)
+                                  default_extension=default_extension,
+                                  encoding=file_encoding)
             files.append(f)
             if cfg.get('verbose'):
                 print("  Selecting '%s'" % (filename))
@@ -275,6 +283,13 @@ def main():
                              " found without a file extension.",
                         default='', dest='default_extension',
                         metavar='extension')
+    parser.add_argument("--file-encoding", action="store",
+                        help="Override encoding to use when attempting"
+                             " to determine an input files text encoding "
+                             "(providing this avoids using `chardet` to"
+                             " automatically detect encoding/s)",
+                        default='', dest='file_encoding',
+                        metavar='encoding')
     parser.add_argument("--max-line-length", action="store", metavar="int",
                         type=int,
                         help="Maximum allowed line"
